#
# spec file for package slib
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           slib
Provides:       scheme:/usr/lib/scheme/slib/umbscheme.init
PreReq:         %install_info_prereq
PreReq:         guile1 coreutils
Version:        3b4
Release:        7.5
Summary:        Portable Scheme Library
License:        SUSE-SLIB
Group:          Development/Languages/Scheme
Url:            http://swissnet.ai.mit.edu/~jaffer/SLIB.html
Source:         http://groups.csail.mit.edu/mac/ftpdir/scm/slib-%{version}.zip
# this is not upstreamable (bnc#754532):
Patch0:         remove-resene-colors.diff
BuildRequires:  unzip
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
SLIB is a portable Scheme library providing compatibility and utility
functions for all standard Scheme implementations.



Authors:
--------
    William R. Campbell <bill@cs.umb.edu>

%prep
%setup -q -n slib
%patch0 -p1

%build

%install
install -m 755 -d $RPM_BUILD_ROOT/usr/share/slib/
install -m 755 -d $RPM_BUILD_ROOT/%{_infodir}/
install -m 644 *.scm *.init $RPM_BUILD_ROOT/usr/share/slib/
install -m 644 slib.info* $RPM_BUILD_ROOT%{_infodir}/

%clean
rm -rf $RPM_BUILD_ROOT

%triggerin -- guile1
# install guile library
# We need new guile for registration, see "Incompatible change in guile 1.8.2".
# During update must be slib-3a5 installed first (See Conflits: slib < 3a5 in guile.spec)
# because of %triggerin in slib, 3a1 for example, though.
if [ -d usr/share/guile/site ] ; then
  GUILE_VERSION=`guile1 -c "(display (version))" | sed "s:\.::g"`
  # guile is instaled
  if [ $GUILE_VERSION -ge 182 ]; then
    # we have guile >= 1.8.2
    if [ ! -e usr/share/guile/site/slib ] ; then
      # link slib library into guile
      ln -sf ../../slib usr/share/guile/site/slib
    fi
    usr/bin/guile1 -c "(use-modules (ice-9 slib)) (require 'new-catalog)"
  fi
fi
exit 0

%triggerpostun -- guile1
# Delete slib library files, only if guile1 was uninstalled.
if ! test -e usr/bin/guile1 ; then
    rm -f usr/share/guile/site/slib
    rm -f usr/share/guile/site/slibcat
    rmdir --ignore-fail-on-non-empty usr/share/guile/site
    rmdir --ignore-fail-on-non-empty usr/share/guile
fi
exit 0

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz
# install guile library
# We need new guile for registration, see "Incompatible change in guile 1.8.2".
# During update must be slib-3a5 installed first (See Conflits: slib < 3a5 in guile.spec)
# because of %triggerin in slib, 3a1 for example, though.
if [ -d usr/share/guile/site -o -e usr/bin/guile1 ] ; then
  GUILE_VERSION=`guile1 -c "(display (version))" | sed "s:\.::g"`
  # guile is instaled
  if [ $GUILE_VERSION -ge 182 ]; then
  # we have guile >= 1.8.2
    if [ ! -d usr/share/guile/site ] ; then
      # This is in orderd to fixup eventually removed guile/site folders
      # which could have happened due to bnc#780827.
      mkdir usr/share/guile/site
    fi
    if [ ! -e usr/share/guile/site/slib ] ; then
      # link slib library into guile
      ln -sf ../../slib usr/share/guile/site/slib
    fi
    usr/bin/guile1 -c "(use-modules (ice-9 slib)) (require 'new-catalog)"
  fi
fi

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz
# Delete guile library, only if slib or guile was uninstalled.
if ! test -d usr/share/slib -a -d usr/share/guile/site ; then
    rm -f usr/share/guile/site/slib
    rm -f usr/share/guile/site/slibcat
fi

%files
%defattr(-,root,root)
%doc ANNOUNCE COPYING ChangeLog FAQ README
%doc %{_infodir}/*
%{_datadir}/slib

%changelog
* Mon Sep  9 2013 pgajdos@suse.com
- updated to 3b4:
  * wttree.scm: Fixed bug where tree balance was lost by deletions
    http://hagi.is.s.u-tokyo.ac.jp/~yh/bst.pdf
  * slib.sh, gosh.init: Added support for (gosh) Gauche-0.9.
  * mitscheme.init: Removed support for defmacro when
    (mit-scheme-release >= 9 0).
  * trsrch.scm (substring?, substring-ci?): Replaced the skip-vector
    with an alist (to work with wide characters).
  * etc. see http://people.csail.mit.edu/jaffer/SLIB.html
* Wed Sep 26 2012 dimstar@opensuse.org
- Fix %%triggerpostun -- guile1 - scriptlet: the binary to check
  for is called guile1, and not anymore guile (due to parallel
  installation needs of guile1 and guile2) Fixes bnc#780827.
- Extend post-install script to always trigger when guile is
  already installed. This special casing with too old guile1
  should never affect us anymore. Only minimal changes to the
  scripts done, in order to have small change for a maintenance
  update.
* Wed May 30 2012 pgajdos@suse.com
- remove Resene color names due license doubt [bnc#754532]
  * remove-resene-colors.diff
* Wed May 16 2012 cfarrell@suse.com
- license update: SUSE-SLIB
  This license was added to the spreadsheet linked from
  license.opensuse.org specifically to handle the non standard SLIB
  license
* Tue Jan 10 2012 pgajdos@suse.com
- using guile1 [bnc#724917]
* Mon Aug 30 2010 pgajdos@suse.cz
- updated to version 3b3:
  * Supports GNU configure.
  * Makefile: Reorganized per <http://www.gnu.org/prep/standards/>.
  * (Guile 1.8.6, 1.8.7, 1.9.7, and 2?): Supported.
  * s7.init: Added init file for S7, part of the Snd sound-editor.
  * Makefile (allfiles): Added "version.txi".
  * Corrected several color problems.
  * qp.scm (qp): Don't truncate symbols when printing.
  * transact.scm (word:lock!): Truncate email components so MS-Word
    style ~$ckfile fits in 162.B.
  * dirs.scm (directory*-for-each): Added.
  * srfi-39.scm (make-parameter, parameterize): Added.
  * grapheps.ps (bargraph, impulse): Fixed for ranges not containing 0.
* Thu Jan 28 2010 pgajdos@suse.cz
- better guile version checking
* Tue Nov 24 2009 pgajdos@suse.cz
- updated to 3b2 (see ANNOUNCE)
* Thu Nov 13 2008 ro@suse.de
- make sure trigger scripts do not fail
* Tue Nov  4 2008 pgajdos@suse.cz
- added coreutils and guile to PreReq [bnc#440993]
* Thu Jul 31 2008 pgajdos@suse.cz
- updated to 3b1:
  o Larceny (Scheme) is supported.
  o scheme48.init (slib:os-strings): Fixed init for 1.7 (and 1.3).
    (defmacro:eval, defmacro:load): Fixed.
  o guile.init (implementation-vicinity): Just (%%site-dir).
    (file-position, gentemp): module-replace!
    (library-vicinity): Try (%%search-load-path "slib/guile.init").
* Mon Feb  4 2008 pgajdos@suse.cz
- added test for version of guile to the %%post and %%triggerin
  (guile >= 1.8.2 is needed for slib registration)
* Wed Dec 19 2007 pgajdos@suse.cz
- updated to 3a5:
  * Draft SRFI-96 "SRFI Prerequisites" specifies the interface
    between implementations and the SLIB library system.
  * Added support for Kawa and SISC.
  * SSAX (xml-parse) module ported from SSAX 5.1.
  * Sort package compatibly upgraded to SRFI-95.
  * Added features SRFI-11 (let-values) and SRFI-28 (format).
  * Updated "guile.init" for Guile 1.8.
  * Updated "mitscheme.init" for versions after 7.7.1.
  * Rewrote scheme48(.init) delete-file using Posix unlink.
  * Fixed problem with macros-that-work.
* Mon Apr  2 2007 sbrabec@suse.cz
- Fixed %%triggerin symlink target (#258261).
* Fri Mar  9 2007 sbrabec@suse.cz
- Fixed scriptlet symlink target.
* Mon Mar  5 2007 sbrabec@suse.cz
- Slib guile library installation moved from guile to slib.
* Fri Sep  8 2006 anicka@suse.cz
- remove manually generated slibcat, fixed in guile
* Thu May  4 2006 sbrabec@suse.cz
- Build as noarch.
* Fri Feb 10 2006 anicka@suse.cz
- install slibcat (fixes #147520), has to be regenerated with every
  update
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Sep  9 2005 anicka@suse.cz
- switch back to 3a1 (#112942)
* Thu Jun 30 2005 anicka@suse.cz
- update to 3a2
* Tue Dec 16 2003 mcihar@suse.cz
- updated to 3a1
- no root for build
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Feb 10 2003 mcihar@suse.cz
- used %%install_info macro (fixes bug #23457)
- updated to version 2d5
* Tue Aug  6 2002 mcihar@suse.cz
- updated to version 2d4
* Thu Dec  6 2001 pmladek@suse.cz
- package splited from the package scheme
- updated to version 2d2
